@@ -18,14 +18,22 @@
 import os
 
 
-def is_root():
+def is_root() -> bool:
     try:
         # Windows doesn't have getuid. We just assume that user is not root. We
         # most likely won't need proper Windows support here anyway.
-        uid = os.getuid()  # pylint: disable=no-member
+        uid = os.getuid()  # type: ignore[attr-defined] # pylint: disable=no-member
     except AttributeError:
         return False
     # User id 0 is reserved for superuser aka root
     if uid == 0:
         return True
     return False
+
+
+def is_docker() -> bool:
+    path = '/proc/self/cgroup'
+    return (os.path.exists('/.dockerenv')
+            or os.path.isfile(path) and any('docker' in line
+                                            for line in open(path))  # noqa: W503,W1514
+            )
