@@ -15,7 +15,7 @@
 # limitations under the License.
 # ---------------------------
 from __future__ import annotations
-from typing import Union, Any, Callable, Optional
+from typing import Union, Any, Callable, Optional, List
 
 from QWeb.internal import browser, javascript
 from QWeb.internal.browser.safari import NAMES as SAFARINAMES
@@ -23,6 +23,8 @@ from QWeb.internal.input_handler import INPUT_HANDLER as input_handler
 from QWeb.internal.exceptions import QWebValueMismatchError, QWebUnexpectedConditionError
 from robot.api import logger
 from robot.libraries.BuiltIn import BuiltIn
+from selenium.common.exceptions import StaleElementReferenceException
+from selenium.webdriver.remote.webelement import WebElement
 import json
 import platform
 import re
@@ -99,6 +101,17 @@ def set_input_handler(input_method: str) -> str:
     return input_method.lower()
 
 
+def get_emulation_pref(device_or_dimension: str) -> dict[str, Any]:
+    """Sets correct mobile emulation option string based on given input
+     (existing device profile name or screen dimensions).
+    """
+    try:
+        width_str, height_str = _parse_pixels(device_or_dimension)
+        return {"deviceMetrics": {"width": int(width_str), "height": int(height_str)}}
+    except ValueError:
+        return {"deviceName": device_or_dimension}
+
+
 def set_line_break(key: str) -> str:
     if key == '\ue000':
         current_browser = browser.get_current_browser().capabilities['browserName']
@@ -246,6 +259,13 @@ def _handle_old_style_prefs(prefs: str) -> dict:
     return d
 
 
+def parse_prefs(prefs: Optional[Any]) -> dict:
+    if isinstance(prefs, dict):
+        return prefs
+
+    return prefs_to_dict(str(prefs).strip())
+
+
 def validate_run_before(value: Union[list[str], str]) -> Optional[Union[list[str], str]]:
     if isinstance(value, list):
         if value[0].lower().startswith("verify"):
@@ -320,3 +340,23 @@ def anchor_to_index(anchor: str) -> int:
     except ValueError:
         index = 0
     return index
+
+
+def remove_duplicates_from_list(new_list: list, result_list: list) -> list:
+    #  remove duplicates (normal search and including shadow search)
+    for el in new_list:
+        if result_list is not None and el not in list(result_list):
+            result_list.append(el)
+    return result_list
+
+
+def remove_stale_elements(elems: Optional[List[WebElement]]) -> Optional[List[WebElement]]:
+    if elems is None:
+        return None
+    # remove staling elements from original list
+    for elem in reversed(elems):
+        try:
+            elem.text
+        except StaleElementReferenceException:
+            elems.remove(elem)
+    return elems
