@@ -68,7 +68,8 @@ def set_config(par: str, val: str) -> Any:
     | HighlightColor_     | Sets the highlight color to use when    |   blue         |
     |                     | element is highlighted.                 |                |
     +---------------------+-----------------------------------------+----------------+
-    | InputHandler_       | Use selenium or pyautogui to input text | selenium       |
+    | InputHandler_       | Use javascript, selenium or pyautogui   | selenium       |
+    |                     | to input text.                          |                |
     +---------------------+-----------------------------------------+----------------+
     | InViewport_         | If set to true every element outside of | False          |
     |                     | current viewport is considered invisible|                |
@@ -539,9 +540,9 @@ def set_config(par: str, val: str) -> Any:
     the web element is writable (enabled). Inserts tab character
     at the end of text.
 
-    Alternative writer "raw" uses pyautogui to input text directly
-    without checking the web element state. This version is intended
-    to be used when the web page doesn't update input element status
+    Alternative writers "raw" and "javascript. "raw" uses pyautogui to input text directly
+    without checking the web element state. "javascript" uses javascript for input.
+    These version are intended to be used when the web page doesn't update input element status
     Selenium compliant way.
 
     Examples
@@ -551,6 +552,9 @@ def set_config(par: str, val: str) -> Any:
          SetConfig      InputHandler        raw
          SetConfig      InputHandler        selenium
 
+         # Use JavaScript to set the text to input element's value attribute
+         SetConfig      InputHandler        javascript
+
     .. _offsetcheck:
 
     ----
