@@ -831,19 +831,23 @@ def get_text(
     ----------------
     \`Is Text\`, \`VerifyText\`
     """
+    anchor_int = util.anchor_to_index(anchor)
     tag = kwargs.get('tag', None)
     if tag:
         try:
-            anchor_int = int(anchor) - 1
             kwargs['element_kw'] = True
-            web_element = element.get_elements_by_attributes(tag, locator, **kwargs)[anchor_int]
+            shadow_dom = CONFIG['ShadowDOM']
+            if shadow_dom:
+                web_element = internal_text.get_items_including_shadow_dom(locator, tag)[anchor_int]
+            else:
+                web_element = element.get_elements_by_attributes(tag, locator, **kwargs)[anchor_int]
         except ValueError as e:
             raise QWebValueError(
                 'Only index is allowed anchor when searching element by it\'s attribute') from e
     elif '//' not in locator:
         web_element = internal_text.get_text_using_anchor(locator, anchor)
     else:
-        web_element = element.get_unique_element_by_xpath(locator, **kwargs)
+        web_element = element.get_unique_element_by_xpath(locator, index=anchor_int, **kwargs)
     text = web_element.text
     if CONFIG['SearchMode']:
         element.draw_borders(web_element)
